# iMath Requests
Python package for communication with the iMath data platform REST API

## Status
[![Build](https://github.com/i3drobotics/imath-requests/actions/workflows/build.yml/badge.svg)](https://github.com/i3drobotics/imath-requests/actions/workflows/build.yml)
[![Release](https://github.com/i3drobotics/imath-requests/actions/workflows/release.yml/badge.svg)](https://github.com/i3drobotics/imath-requests/actions/workflows/release.yml)

## Install
Install the package using pip:
```
python -m pip install imath-requests
```

## Development
Please read the guides for [contributors](.github/CONTRIBUTOR.md) and [maintainers](.github/MAINTAINER.md) using this repository.

Please read the guide for [branches](.github/BRANCHES.md) and how they are used in this repository.